@@ -8,6 +8,7 @@ from rich.progress import Progress, TextColumn, BarColumn, DownloadColumn, TimeE
 from ruamel import yaml
 
 from piperider_cli import __version__
+from piperider_cli.error import PipeRiderNoDefaultProjectError
 from piperider_cli.event import load_user_profile, update_user_profile
 
 PIPERIDER_CLOUD_SERVICE = 'https://cloud.piperider.io/'
@@ -57,7 +58,7 @@ class CloudServiceHelper:
     def update_config(self, options: dict):
         cloud_config = self.get_config()
         cloud_config.update(options)
-        update_user_profile({'cloud_config': cloud_config})
+        self.user_profile = update_user_profile({'cloud_config': cloud_config})
 
     def update_api_token(self):
         if self.api_token:
@@ -181,15 +182,18 @@ class PipeRiderCloud:
         if response.status_code != 200:
             return None
 
-        for project in response.json():
-            if project.get('id'):
-                # Legacy projects api response
-                if project.get('is_default'):
-                    return PipeRiderProject(project)
-            else:
-                # New projects api response
-                for p in project.get('projects', [])[:1]:
-                    return PipeRiderProject(p)
+        responseData = response.json()
+
+        def genProjects():
+            for workspace in responseData.get('data', []):
+                for project in workspace.get('projects', []):
+                    yield project
+
+        projects = list(genProjects())
+        if len(projects) == 1:
+            return PipeRiderProject(projects[0])
+        else:
+            raise PipeRiderNoDefaultProjectError()
 
     def get_default_workspace_and_project(self):
         if not self.available:
@@ -277,6 +281,20 @@ class PipeRiderCloud:
 
             return response.json()
 
+    def share_run_report(self, workspace_name: str, project_name: str, run_id: int):
+        if not self.available:
+            self.raise_error()
+
+        url = self.service.url(
+            f'/api/v2/workspaces/{workspace_name}/projects/{project_name}/runs/{run_id}/share')
+        headers = self.service.auth_headers()
+        response = requests.post(url, headers=headers)
+
+        if response.status_code != 200:
+            return None
+
+        return response.json()
+
     def compare_reports(self, base_id: int, target_id: int, tables_from, project: PipeRiderProject):
         if not self.available:
             self.raise_error()
