@@ -11,7 +11,7 @@ from rich.console import Console
 from rich.prompt import Prompt
 from rich.table import Table
 
-from piperider_cli import datetime_to_str, open_report_in_browser, str_to_datetime
+from piperider_cli import datetime_to_str, open_report_in_browser, str_to_datetime, get_run_json_path
 from piperider_cli.cloud import PipeRiderCloud, PipeRiderProject
 from piperider_cli.compare_report import CompareReport, RunOutput
 from piperider_cli.datasource import FANCY_USER_INPUT
@@ -169,8 +169,10 @@ def setup_cloud_default_config(options: dict = None):
             console.print(f'[[bold green]Config[/bold green]] Default project is set to \'{project_name}\'')
         else:
             console.print(f"[[yellow]Skip[/yellow]] Project '{project_name}' does not exist.")
+
     if piperider_cloud.config.get('default_project') is None:
-        CloudConnector.select_project()
+        no_interaction = options and options.get('no_interaction')
+        CloudConnector.select_project(no_interaction=no_interaction)
 
 
 def select_reports(report_dir=None, datasource=None) -> List[RunOutput]:
@@ -241,14 +243,14 @@ def upload_to_cloud(run: RunOutput, debug=False, project: PipeRiderProject = Non
 
     if response.get('success') is True:
         run_id = response.get('id')
+        report_url = response.get('url')
         if run_id:
-            report_url = f'{piperider_cloud.service.cloud_host}/{project.workspace_name}/{project.name}/runs/{run_id}'
             _patch_cloud_upload_response(run.path, project, run_id)
-        else:
-            report_url = 'N/A'
+
         return {
             'success': True,
             'message': response.get("message"),
+            'run_id': run_id,
             'report_url': report_url,
             'file_path': run.path
         }
@@ -279,14 +281,10 @@ def get_run_report_id(project: PipeRiderProject, report_key: str) -> Optional[in
     return None
 
 
-def create_compare_reports(base_id: int, target_id: int, tables_from, project: PipeRiderProject = None) -> dict:
+def create_compare_reports(base_id: str, target_id: str, tables_from, project: PipeRiderProject = None) -> dict:
     if project is None:
         project = piperider_cloud.get_default_project()
     response = piperider_cloud.compare_reports(base_id, target_id, tables_from, project=project)
-    if response:
-        url = f'{piperider_cloud.service.cloud_host}/{project.workspace_name}/{project.name}/runs/{base_id}/comparison/{target_id}'
-        response['url'] = url
-
     return response
 
 
@@ -359,17 +357,16 @@ class CloudConnector:
         return 0
 
     @staticmethod
-    def upload_latest_report(report_dir=None, debug=False, open_report=False, force_upload=False,
-                             auto_upload=False, project_name: str = None) -> int:
+    def upload_latest_report(report_dir=None, debug=False, open_report=False, enable_share=False,
+                             project_name: str = None) -> int:
         filesystem = FileSystem(report_dir=report_dir)
-        latest_report_path = os.path.join(filesystem.get_output_dir(), 'latest', 'run.json')
+        latest_report_path = get_run_json_path(filesystem.get_output_dir())
         return CloudConnector.upload_report(latest_report_path, debug=debug, open_report=open_report,
-                                            force_upload=force_upload, auto_upload=auto_upload,
-                                            project_name=project_name)
+                                            enable_share=enable_share, project_name=project_name)
 
     @staticmethod
     def upload_report(report_path=None, report_dir=None, datasource=None, debug=False, open_report=False,
-                      force_upload=False, auto_upload=False, project_name=None, show_progress=True) -> int:
+                      enable_share=False, project_name=None, show_progress=True) -> int:
         if piperider_cloud.available is False:
             console.rule('Please login PipeRider Cloud first', style='red')
             return 1
@@ -429,6 +426,10 @@ class CloudConnector:
             url = response.get('report_url')
             open_report_in_browser(url, True)
 
+        if enable_share:
+            run_id = response.get('run_id')
+            CloudConnector.share_run_report(run_id, debug)
+
         return rc
 
     @staticmethod
@@ -496,6 +497,25 @@ class CloudConnector:
             with open(summary_file, 'w') as f:
                 f.write(response.get('summary'))
 
+    @staticmethod
+    def share_run_report(run_id=None, debug=False):
+        if piperider_cloud.available is False:
+            console.rule('Please login PipeRider Cloud first', style='red')
+            return 1
+
+        workspace_name, project_name = piperider_cloud.get_default_workspace_and_project()
+        if workspace_name is None or project_name is None:
+            console.rule('Please select a workspace and a project first', style='red')
+            return 1
+
+        if debug:
+            console.print(f"Sharing comparison report id={run_id}")
+        piperider_cloud.share_run_report(
+            workspace_name=workspace_name,
+            project_name=project_name,
+            run_id=run_id
+        )
+
     @staticmethod
     def share_compare_report(base_id=None, target_id=None, debug=False):
         if piperider_cloud.available is False:
@@ -509,17 +529,12 @@ class CloudConnector:
 
         if debug:
             console.print(f"Sharing comparison report id={base_id} ... id={target_id}")
-        response = piperider_cloud.share_compare_report(
+        piperider_cloud.share_compare_report(
             workspace_name=workspace_name,
             project_name=project_name,
             base_id=base_id,
             target_id=target_id,
         )
-        sharing_url = None
-
-        if response:
-            sharing_url = f'{piperider_cloud.service.cloud_host}/runs/sharing/comparison/{response.get("sharing_id")}'
-        return sharing_url
 
     @staticmethod
     def list_projects(debug=False) -> int:
@@ -560,9 +575,12 @@ class CloudConnector:
         pass
 
     @staticmethod
-    def select_project(project_name: str = None, datasource: str = None, debug: bool = False) -> int:
+    def select_project(project_name: str = None,
+                       datasource: str = None,
+                       no_interaction: bool = False,
+                       debug: bool = False) -> int:
 
-        def _project_selector():
+        def _select_project_by_inquirer(project_list: list) -> PipeRiderProject:
             arrow_alias_msg = ''
             if sys.platform == "win32" or sys.platform == "cygwin":
                 # change readchar key UP & DOWN by 'w' and 's'
@@ -573,7 +591,7 @@ class CloudConnector:
             projects = [
                 (f"{p.get('workspace_name')}/{p.get('name')}" if p.get('workspace_name') else p.get('name'),
                  PipeRiderProject(p))
-                for p in piperider_cloud.list_projects()]
+                for p in project_list]
 
             if len(projects) == 1:
                 _, p = projects[0]
@@ -591,8 +609,44 @@ class CloudConnector:
                 return answers['selected_project']
             return None
 
+        def _select_project_by_rich(project_list: list) -> PipeRiderProject:
+            console = Console()
+            console.print('[[yellow]?[/yellow]] Please select a project as default project:')
+            i = 0
+            for p in project_list:
+                i += 1
+                if p.get('workspace_name'):
+                    project_name = f"{p.get('workspace_name')}/{p.get('name')}"
+                else:
+                    project_name = p.get('name')
+                console.print(f"[[blue]{i}[/blue]] {project_name}")
+
+            while True:
+                try:
+                    type_idx = Prompt.ask('[[yellow]?[/yellow]] Select a number')
+                    type_idx = int(type_idx)
+                except EOFError as e:
+                    raise e
+                except Exception:
+                    type_idx = 0
+                if type_idx > len(project_list) or type_idx < 1:
+                    console.print('    [[red]Error[/red]] Input is not a valid index value. Please try again.')
+                else:
+                    answer = PipeRiderProject(project_list[type_idx - 1])
+                    break
+            return answer if answer is not None else ''
+
         if project_name is None:
-            project = _project_selector()
+            existing_project_list = piperider_cloud.list_projects()
+            if no_interaction is True:
+                if len(existing_project_list) == 0:
+                    console.print('[[bold red]Error[/bold red]] No project exists')
+                    return 1
+                project = PipeRiderProject(existing_project_list[0])
+            elif FANCY_USER_INPUT:
+                project = _select_project_by_inquirer(existing_project_list)
+            else:
+                project = _select_project_by_rich(existing_project_list)
         else:
             project = piperider_cloud.get_project_by_name(project_name)
             if project is None:
