@@ -12,7 +12,7 @@ from rich.console import Console
 
 import piperider_cli.hack.inquirer as inquirer_hack
 from piperider_cli import datetime_to_str, str_to_datetime, clone_directory, \
-    raise_exception_when_directory_not_writable
+    raise_exception_when_directory_not_writable, open_report_in_browser
 from piperider_cli.filesystem import FileSystem
 from piperider_cli.generate_report import setup_report_variables
 
@@ -580,10 +580,25 @@ def prepare_default_output_path(filesystem: FileSystem, created_at):
     # Create a symlink pointing to the latest comparison directory
     if os.path.islink(latest_symlink_path):
         os.unlink(latest_symlink_path)
+
+    console = Console()
     if not os.path.exists(latest_symlink_path):
-        os.symlink(latest_source, latest_symlink_path)
+        try:
+            os.symlink(latest_source, latest_symlink_path)
+        except OSError as e:
+            """
+            System Error Codes:
+                ERROR_PRIVILEGE_NOT_HELD
+                1314 (0x522)
+                A required privilege is not held by the client.
+                https://learn.microsoft.com/en-us/windows/win32/debug/system-error-codes--1300-1699-
+            """
+            if e.winerror is not None and e.winerror == 1314:
+                console.print(
+                    f'[bold yellow]Warning:[/bold yellow] {e}. To solve this, run piperider as an administrator')
+            else:
+                raise e
     else:
-        console = Console()
         console.print(f'[bold yellow]Warning: {latest_symlink_path} already exists[/bold yellow]')
 
     return comparison_path
@@ -720,8 +735,8 @@ class CompareReport(object):
 
     @staticmethod
     def exec(*, a=None, b=None, last=None, datasource=None, report_dir=None, output=None, tables_from='all',
-             summary_file=None, force_upload=False, enable_share=False, project_name: str = None, debug=False,
-             show_progress=False):
+             summary_file=None, force_upload=False, enable_share=False, open_report=False, project_name: str = None,
+             debug=False, show_progress=False):
         console = Console()
         console.rule('Comparison report', style='bold blue')
 
@@ -778,10 +793,14 @@ class CompareReport(object):
         default_report_directory = prepare_default_output_path(filesystem, data_id)
         output_report(default_report_directory)
         output_summary(default_report_directory, summary_data)
-        report_path = os.path.join(filesystem.get_comparison_dir(), 'latest', 'index.html')
-        summary_md_path = os.path.join(filesystem.get_comparison_dir(), 'latest', 'summary.md')
 
-        sharing_url = None
+        comparison_dir = filesystem.get_comparison_dir()
+        report_path = os.path.join(comparison_dir, 'latest', 'index.html')
+        summary_md_path = os.path.join(comparison_dir, 'latest', 'summary.md')
+        if not os.path.exists(os.path.join(comparison_dir, 'latest')):
+            report_path = os.path.join(default_report_directory, 'index.html')
+            summary_md_path = os.path.join(default_report_directory, 'summary.md')
+
         if enable_share:
             if report.a.cloud is None or report.b.cloud is None:
                 console.print(
@@ -790,7 +809,7 @@ class CompareReport(object):
                 from piperider_cli.cloud_connector import CloudConnector
                 base = str(report.a.cloud.get('run_id'))
                 target = str(report.b.cloud.get('run_id'))
-                sharing_url = CloudConnector.share_compare_report(base, target)
+                CloudConnector.share_compare_report(base, target)
 
         if output:
             clone_directory(default_report_directory, output)
@@ -810,8 +829,12 @@ class CompareReport(object):
         console.print(f"Comparison summary: {summary_md_path}")
         if report_url:
             console.print(f"Comparison report URL: {report_url}")
-        if sharing_url:
-            console.print(f"Comparison sharing report: {sharing_url}")
+
+        if open_report:
+            if report_url:
+                open_report_in_browser(report_url, True)
+            else:
+                open_report_in_browser(report_path)
 
         if debug:
             # Write comparison data to file
