@@ -85,7 +85,7 @@ class DataSource(metaclass=ABCMeta):
     def verify_connection(self):
         engine = self.get_engine_by_database()
         with engine.connect() as conn:
-            stmt = select([text('1 as id')])
+            stmt = select(text('1 as id'))
             conn.execute(stmt)
         return
 
@@ -192,8 +192,11 @@ class DataSource(metaclass=ABCMeta):
             try:
                 type_idx = Prompt.ask('[[yellow]?[/yellow]] Select a number: ')
                 type_idx = int(type_idx)
+            except EOFError as e:
+                raise e
             except Exception:
                 type_idx = 0
+
             if type_idx > len(source_choices) or type_idx < 1:
                 console.print('    [[red]Error[/red]] Input is not a valid index value. Please try again.')
             else:
@@ -263,10 +266,12 @@ def _list_datasource_providers():
     from .redshift import RedshiftDataSource
     from .survey import UserSurveyMockDataSource
     from .duckdb import DuckDBDataSource, CsvDataSource, ParquetDataSource
+    from .athena import AthenaDataSource
     return {
         'snowflake': SnowflakeDataSource,
         'bigquery': BigQueryDataSource,
         'redshift': RedshiftDataSource,
+        'athena': AthenaDataSource,
         'postgres': PostgresDataSource,
         'sqlite': SqliteDataSource,
         'duckdb': DuckDBDataSource,
