@@ -65,6 +65,7 @@ class TrackCommand(Command):
     def invoke(self, ctx: Context) -> t.Any:
         status = False
         try:
+            self._apply_project_parameters(ctx)
 
             ret = super(TrackCommand, self).invoke(ctx)
             if ret is None or ret == 0:
@@ -74,13 +75,38 @@ class TrackCommand(Command):
         except Exception as e:
             if _enable_trackback:
                 print(traceback.format_exc())
-            self._show_error_message(e, ctx.params)
+
             if isinstance(e, PipeRiderError):
                 if e.hint:
                     self._show_hint_message(e.hint)
-            sentry_sdk.capture_exception(e)
+
+            ignored = False
+            if isinstance(e, EOFError):
+                ignored = True
+                self._show_error_message(
+                    f"The '{ctx.command.name}' command could not be executed "
+                    f"due to the unavailability of STDIN, which is required to receive user input.", ctx.params)
+
+                if ctx.command.name in ['login', 'select_project']:
+                    self._show_hint_message("""
+Consider using the following options to select a project:
+
+    - To automatically select the first project, use `--no-interaction` option.
+    - To select a specific project, use the `--project` option by the project name.
+                    """.strip())
+            else:
+                ignored = False
+                self._show_error_message(e, ctx.params)
+
+            if not ignored:
+                sentry_sdk.capture_exception(e)
             sentry_sdk.flush()
             sys.exit(1)
         finally:
             event.log_usage_event(ctx.command.name, ctx.params, status)
             event.flush_events(ctx.command.name)
+
+    def _apply_project_parameters(self, ctx):
+        # sc-30888 use PIPERIDER_API_PROJECT if `--project` did not set
+        if 'project' in ctx.params and ctx.params.get('project') is None:
+            ctx.params['project'] = os.environ.get('PIPERIDER_API_PROJECT')
