@@ -1,4 +1,5 @@
 import os
+import sys
 from abc import ABCMeta
 from typing import Dict, List
 
@@ -10,6 +11,7 @@ from ruamel import yaml
 from piperider_cli import load_json, round_trip_load_yaml
 from piperider_cli.configuration import PIPERIDER_WORKSPACE_NAME
 from piperider_cli.error import RecipeConfigException
+from piperider_cli.recipes.utils import git_checkout_to
 
 PIPERIDER_RECIPES_SCHEMA_PATH = os.path.join(os.path.dirname(__file__), 'recipe_schema.json')
 PIPERIDER_RECIPES_PATH = os.path.join(os.getcwd(), PIPERIDER_WORKSPACE_NAME, 'compare')
@@ -222,18 +224,21 @@ def execute_recipe(model: RecipeModel, current_branch, debug=False, recipe_type=
         if debug:
             console.print(f"Exit code: {exit_code}")
         if exit_code != 0:
-            raise Exception(f"Recipe dbt command failed: '{cmd}' with exit code: {exit_code}")
+            console.print(
+                f"[bold yellow]Warning: [/bold yellow] Recipe dbt command failed: '{cmd}' with exit code: {exit_code}")
+            sys.exit(exit_code)
         console.print()
 
     # model.piperider.commands
     for cmd in model.piperider.commands or []:
-
         console.print(f"Run: \[{cmd}]")
         exit_code = execute_command(cmd, model.piperider.envs())
         if debug:
             console.print(f"Exit code: {exit_code}")
         if exit_code != 0:
-            raise Exception(f"Recipe piperider command failed: '{cmd}' with exit code: {exit_code}")
+            console.print(
+                f"[bold yellow]Warning: [/bold yellow] Recipe piperider command failed: '{cmd}' with exit code: {exit_code}")
+            sys.exit(exit_code)
         console.print()
 
 
@@ -261,7 +266,7 @@ def switch_merge_base_branch(a: str, b: str) -> str:
 
 def switch_branch(branch_name):
     from piperider_cli.recipes.utils import git_switch_to
-    git_switch_to(branch_name)
+    git_checkout_to(branch_name)
 
 
 def execute_configuration(cfg: RecipeConfiguration, debug=False):
@@ -276,10 +281,14 @@ def execute_configuration(cfg: RecipeConfiguration, debug=False):
 
     try:
         console.rule("Recipe executor: base phase")
-        execute_recipe(cfg.base, current_branch, recipe_type='base', debug=debug)
+        target_branch = cfg.target.branch or current_branch
+        execute_recipe(cfg.base, target_branch, recipe_type='base', debug=debug)
 
         console.rule("Recipe executor: target phase")
         execute_recipe(cfg.target, current_branch, recipe_type='target', debug=debug)
+    except Exception as e:
+        console.rule("Recipe executor: error occurred", style="red")
+        raise e
     finally:
         if current_branch is not None:
             # switch back to the original branch
