@@ -435,10 +435,25 @@ def prepare_default_output_path(filesystem: FileSystem, created_at, ds):
     # Create a symlink pointing to the latest output directory
     if os.path.islink(latest_symlink_path):
         os.unlink(latest_symlink_path)
+
+    console = Console()
     if not os.path.exists(latest_symlink_path):
-        os.symlink(latest_source, latest_symlink_path)
+        try:
+            os.symlink(latest_source, latest_symlink_path)
+        except OSError as e:
+            """
+            System Error Codes:
+                ERROR_PRIVILEGE_NOT_HELD
+                1314 (0x522)
+                A required privilege is not held by the client.
+                https://learn.microsoft.com/en-us/windows/win32/debug/system-error-codes--1300-1699-
+            """
+            if e.winerror is not None and e.winerror == 1314:
+                console.print(
+                    f'[bold yellow]Warning:[/bold yellow] {e}. To solve this, run piperider as an administrator')
+            else:
+                raise e
     else:
-        console = Console()
         console.print(f'[bold yellow]Warning: {latest_symlink_path} already exists[/bold yellow]')
 
     return output_path
@@ -571,6 +586,7 @@ def check_dbt_manifest_compatibility(ds: DataSource, dbt_state_dir: str):
     def filter_schema(model):
         model_schema = model.get('schema', '')
         return model_schema == schema or model_schema.startswith(f'{schema}_')
+
     filtered_models = list(filter(filter_schema, models))
 
     if len(models) != len(filtered_models):
@@ -604,9 +620,9 @@ def get_dbt_state_dir(dbt_state_dir, dbt_config, ds, dbt_run_results):
     if not dbtutil.is_dbt_state_ready(dbt_state_dir):
         return None, f"[bold red]Error:[/bold red] No available 'manifest.json' under '{dbt_state_dir}'"
 
-    if not check_dbt_manifest_compatibility(ds, dbt_state_dir):
-        return None, f"[bold red]Error:[/bold red] Target mismatched. " \
-                     f"Please run 'dbt compile -t {dbt_config.get('target')}' to generate the new manifest"
+    if os.environ.get('PIPERIDER_SKIP_TARGET_CHECK', None) != '1':
+        if not check_dbt_manifest_compatibility(ds, dbt_state_dir):
+            return None, f"[bold red]Error:[/bold red] Target mismatched. Please run 'dbt compile -t {dbt_config.get('target')}' to generate the new manifest, or set the environment variable 'PIPERIDER_SKIP_TARGET_CHECK=1' to skip the check."
 
     if dbt_run_results:
         if not dbtutil.is_dbt_run_results_ready(dbt_state_dir):
